@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { LambdaToDynamoDBProps,  LambdaToDynamoDB } = require('@aws-solutions-constructs/aws-lambda-dynamodb');
 
 const props: LambdaToDynamoDBProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         code: lambda.Code.asset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
@@ -60,11 +59,11 @@ new LambdaToDynamoDB(scope: Construct, id: string, props: LambdaToDynamoDBProps)
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user provided props to override the default props for Lambda function|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
 |existingTableObj?|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored|
+|tablePermissions?|`string`|Optional table permissions to grant to the Lambda function. One of the following may be specified: `All`, `Read`, `ReadWrite`, `Write`.|
 
 ## Pattern Properties
 
@@ -125,20 +124,20 @@ class LambdaToDynamoDB(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        table_permissions: typing.Optional[str] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
 
         access:
         :access:: public
@@ -148,11 +147,11 @@ class LambdaToDynamoDB(
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
         props = LambdaToDynamoDBProps(
-            deploy_lambda=deploy_lambda,
             dynamo_table_props=dynamo_table_props,
             existing_lambda_obj=existing_lambda_obj,
             existing_table_obj=existing_table_obj,
             lambda_function_props=lambda_function_props,
+            table_permissions=table_permissions,
         )
 
         jsii.create(LambdaToDynamoDB, self, [scope, id, props])
@@ -172,29 +171,29 @@ class LambdaToDynamoDB(
     jsii_type="@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDBProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "dynamo_table_props": "dynamoTableProps",
         "existing_lambda_obj": "existingLambdaObj",
         "existing_table_obj": "existingTableObj",
         "lambda_function_props": "lambdaFunctionProps",
+        "table_permissions": "tablePermissions",
     },
 )
 class LambdaToDynamoDBProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        table_permissions: typing.Optional[str] = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
 
         summary:
         :summary:: The properties for the LambdaToDynamoDB Construct
@@ -205,9 +204,7 @@ class LambdaToDynamoDBProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
                 **lambda_function_props
             )
-        self._values = {
-            "deploy_lambda": deploy_lambda,
-        }
+        self._values = {}
         if dynamo_table_props is not None:
             self._values["dynamo_table_props"] = dynamo_table_props
         if existing_lambda_obj is not None:
@@ -216,17 +213,8 @@ class LambdaToDynamoDBProps:
             self._values["existing_table_obj"] = existing_table_obj
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
-
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new lambda function or use an existing lambda function.
-
-        If set to false, you must provide a lambda function object as ``existingObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
+        if table_permissions is not None:
+            self._values["table_permissions"] = table_permissions
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -239,9 +227,7 @@ class LambdaToDynamoDBProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -261,15 +247,24 @@ class LambdaToDynamoDBProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used
         """
         return self._values.get("lambda_function_props")
 
+    @builtins.property
+    def table_permissions(self) -> typing.Optional[str]:
+        """Optional table permissions to grant to the Lambda function.
+
+        One of the following may be specified: "All", "Read", "ReadWrite", "Write".
+
+        default
+        :default: - Read/write access is given to the Lambda function if no value is specified.
+        """
+        return self._values.get("table_permissions")
+
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
